Crate contract_extrinsics

Crate contract_extrinsics 

Re-exports

pub use events::DisplayEvents;
pub use extrinsic_opts::ExtrinsicOptsBuilder;
pub use upload::UploadCommandBuilder;
pub use upload::UploadExec;
pub use upload::UploadResult;

Modules

events
extrinsic_calls
extrinsic_opts
pallet_contracts_primitives
upload

Structs

CallCommandBuilder
A builder for the call command.
CallExec
ContractArtifacts
Contract artifacts for use with extrinsic commands.
ContractInfo
ContractMessageTranscoder
Encode strings to SCALE encoded smart contract calls. Decode SCALE encoded smart contract events and return values into Value objects.
ContractStorage
ContractStorageLayout
Represents storage cells containing values and type information for the contract.
ContractStorageRpc
Methods for querying contracts over RPC.
GenericError
InstantiateArgs
InstantiateCommandBuilder
A builder for the instantiate command.
InstantiateDryRunResult
Result of the contract call
InstantiateExec
InstantiateExecResult
A struct representing the result of an instantiate command execution.
RawParams
RemoveCommandBuilder
A builder for the remove command.
RemoveExec
RemoveResult
A struct representing the result of an remove command execution.
RpcRequest
TokenMetadata
TrieId
A contract’s child trie id.
WasmCode
The Wasm code of a contract.

Enums

BalanceVariant
Represents different formats of a balance
Code
Reference to an existing code hash or a new Wasm module.
ContractStorageCell
Represents the storage cell value.
ErrorVariant

Functions

fetch_all_contracts
Fetch all contract addresses from the storage using the provided client.
fetch_contract_info
Fetch the contract info from the storage using the provided client.
fetch_wasm_code
Fetch the contract wasm code from the storage using the provided client and code hash.
url_to_string