pub async fn fetch_wasm_code<C: Config>(
client: &OnlineClient<C>,
rpc: &LegacyRpcMethods<C>,
hash: &C::Hash,
) -> Result<Vec<u8>>Expand description
Fetch the contract wasm code from the storage using the provided client and code hash.
pub async fn fetch_wasm_code<C: Config>(
client: &OnlineClient<C>,
rpc: &LegacyRpcMethods<C>,
hash: &C::Hash,
) -> Result<Vec<u8>>Fetch the contract wasm code from the storage using the provided client and code hash.