pub struct RemoveExec<C: Config, E: Environment, Signer: Clone> { /* private fields */ }Implementations
Sourceimpl<C: Config, E: Environment, Signer> RemoveExec<C, E, Signer>where
C::Hash: IntoVisitor + EncodeAsType,
C::AccountId: IntoVisitor,
<C::ExtrinsicParams as ExtrinsicParams<C>>::Params: From<<DefaultExtrinsicParams<C> as ExtrinsicParams<C>>::Params>,
Signer: Signer<C> + Clone,
impl<C: Config, E: Environment, Signer> RemoveExec<C, E, Signer>where
C::Hash: IntoVisitor + EncodeAsType,
C::AccountId: IntoVisitor,
<C::ExtrinsicParams as ExtrinsicParams<C>>::Params: From<<DefaultExtrinsicParams<C> as ExtrinsicParams<C>>::Params>,
Signer: Signer<C> + Clone,
Sourcepub async fn remove_code(&self) -> Result<RemoveResult<C, E>, ErrorVariant>
pub async fn remove_code(&self) -> Result<RemoveResult<C, E>, ErrorVariant>
Removes a contract code from the blockchain.
This function removes a contract code with the specified code hash from the blockchain, ensuring that it’s no longer available for instantiation or execution. It interacts with the blockchain’s runtime API to execute the removal operation and provides the resulting events from the removal.
Returns the RemoveResult containing the events generated from the contract
code removal, or an error in case of failure.
Sourcepub fn final_code_hash(&self) -> C::Hash
pub fn final_code_hash(&self) -> C::Hash
Returns the final code hash.
Sourcepub fn opts(&self) -> &ExtrinsicOpts<C, E, Signer>
pub fn opts(&self) -> &ExtrinsicOpts<C, E, Signer>
Returns the extrinsic options.
Sourcepub fn client(&self) -> &OnlineClient<C>
pub fn client(&self) -> &OnlineClient<C>
Returns the client.
Sourcepub fn transcoder(&self) -> &ContractMessageTranscoder
pub fn transcoder(&self) -> &ContractMessageTranscoder
Returns the contract message transcoder.