Re-exports
pub use events::DisplayEvents;pub use extrinsic_opts::ExtrinsicOptsBuilder;pub use upload::UploadCommandBuilder;pub use upload::UploadExec;pub use upload::UploadResult;
Modules
Structs
- Call
Command Builder - A builder for the call command.
- Call
Exec - Contract
Artifacts - Contract artifacts for use with extrinsic commands.
- Contract
Info - Contract
Message Transcoder - Encode strings to SCALE encoded smart contract calls.
Decode SCALE encoded smart contract events and return values into
Valueobjects. - Contract
Storage - Contract
Storage Layout - Represents storage cells containing values and type information for the contract.
- Contract
Storage Rpc - Methods for querying contracts over RPC.
- Generic
Error - Instantiate
Args - Instantiate
Command Builder - A builder for the instantiate command.
- Instantiate
DryRun Result - Result of the contract call
- Instantiate
Exec - Instantiate
Exec Result - A struct representing the result of an instantiate command execution.
- RawParams
- Remove
Command Builder - A builder for the remove command.
- Remove
Exec - Remove
Result - A struct representing the result of an remove command execution.
- RpcRequest
- Token
Metadata - TrieId
- A contract’s child trie id.
- Wasm
Code - The Wasm code of a contract.
Enums
- Balance
Variant - Represents different formats of a balance
- Code
- Reference to an existing code hash or a new Wasm module.
- Contract
Storage Cell - Represents the storage cell value.
- Error
Variant
Functions
- fetch_
all_ contracts - Fetch all contract addresses from the storage using the provided client.
- fetch_
contract_ info - Fetch the contract info from the storage using the provided client.
- fetch_
wasm_ code - Fetch the contract wasm code from the storage using the provided client and code hash.
- url_
to_ string